namespace Utilities.PPCEmulatorFileSender
{
	/// <summary>
	/// A simple form application to copy multiple files to a
	/// pocket pc emulator.
	/// </summary>
	public class MainForm : System.Windows.Forms.Form
	{
		#region Variables
		private System.Collections.ArrayList deviceList;
		private Microsoft.VisualStudio.DeviceConnectivity.IConManDataStore store;
		private Properties props;
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.Button exitButton;
		private System.Windows.Forms.Button copyButton;
		private System.Windows.Forms.TextBox sourceTextBox;
		private System.Windows.Forms.GroupBox sourceGroupBox;
		private System.Windows.Forms.GroupBox destinationGroupBox;
		private System.Windows.Forms.ComboBox devicesComboBox;
		private System.Windows.Forms.ComboBox destinationComboBox;
		private System.Windows.Forms.Button sourceSelectFile;
		private System.Windows.Forms.Button sourceSelectFolder;
		private System.Windows.Forms.ProgressBar fileProgressBar;
		private System.Windows.Forms.ProgressBar overallProgressBar;
		private System.Windows.Forms.GroupBox fileGroupBox;
		private System.Windows.Forms.GroupBox overallGroupBox;
		private System.Windows.Forms.CheckBox createDirCheckBox;
		private System.Windows.Forms.OpenFileDialog openFileDialog;
		private System.Windows.Forms.TextBox matchTextBox;
		private System.Windows.Forms.Label folderMatchLabel;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.GroupBox devicesGroupBox;
		#endregion

		#region Constructor/Main/Dispose
		public MainForm()
		{
			// read in the saved properties
			props = new Properties();
			props = props.Deserialize();

			// initialize the gui
			InitializeComponent();
			deviceList = new System.Collections.ArrayList();
			LoadAllPlatforms();
			FillDeviceList();

			// load saved values
			if (this.devicesComboBox.Items.Count > props.SelectedDevice &&
				this.devicesComboBox.Items.Count > 0)
			{
				this.devicesComboBox.SelectedIndex = props.SelectedDevice;
			}
			this.sourceTextBox.Text = props.SourceFiles;
			foreach (string s in this.props.Destinations)
			{
				this.destinationComboBox.Items.Add(s);
			}
			if (this.destinationComboBox.Items.Count > props.DestinationDirectory &&
				this.destinationComboBox.Items.Count > 0)
			{
				this.destinationComboBox.SelectedIndex = props.DestinationDirectory;
			}
			this.createDirCheckBox.Checked = props.CreateDirectory;
			this.matchTextBox.Text = props.SourceMatch;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			try
			{
				props.SelectedDevice = this.devicesComboBox.SelectedIndex;
				props.SourceFiles = string.Copy(this.sourceTextBox.Text);
				props.Destinations.Clear();
				foreach (string s in this.destinationComboBox.Items)
				{
					props.Destinations.Add(s);
				}
				props.DestinationDirectory = this.destinationComboBox.SelectedIndex;
				props.CreateDirectory = this.createDirCheckBox.Checked;
				props.SourceMatch = this.matchTextBox.Text;
				props.Serialize();
			}
			catch (System.Exception e)
			{
				System.Windows.Forms.MessageBox.Show(e.ToString());
			}

			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private static void Main(string[] args)
		{
			/*
				* set the visual stype to xp
				* bug with .NET 1.1 requires that
				* DoEvents() is called after enabling
				* visual styles
				*/
			System.Windows.Forms.Application.EnableVisualStyles();
			System.Windows.Forms.Application.DoEvents();
			System.Windows.Forms.Application.Run(new MainForm());
		}
		#endregion

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MainForm));
			this.devicesGroupBox = new System.Windows.Forms.GroupBox();
			this.devicesComboBox = new System.Windows.Forms.ComboBox();
			this.exitButton = new System.Windows.Forms.Button();
			this.copyButton = new System.Windows.Forms.Button();
			this.sourceTextBox = new System.Windows.Forms.TextBox();
			this.sourceSelectFile = new System.Windows.Forms.Button();
			this.sourceSelectFolder = new System.Windows.Forms.Button();
			this.fileProgressBar = new System.Windows.Forms.ProgressBar();
			this.fileGroupBox = new System.Windows.Forms.GroupBox();
			this.overallGroupBox = new System.Windows.Forms.GroupBox();
			this.overallProgressBar = new System.Windows.Forms.ProgressBar();
			this.sourceGroupBox = new System.Windows.Forms.GroupBox();
			this.destinationGroupBox = new System.Windows.Forms.GroupBox();
			this.createDirCheckBox = new System.Windows.Forms.CheckBox();
			this.destinationComboBox = new System.Windows.Forms.ComboBox();
			this.openFileDialog = new System.Windows.Forms.OpenFileDialog();
			this.matchTextBox = new System.Windows.Forms.TextBox();
			this.folderMatchLabel = new System.Windows.Forms.Label();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.devicesGroupBox.SuspendLayout();
			this.fileGroupBox.SuspendLayout();
			this.overallGroupBox.SuspendLayout();
			this.sourceGroupBox.SuspendLayout();
			this.destinationGroupBox.SuspendLayout();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// devicesGroupBox
			// 
			this.devicesGroupBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.devicesGroupBox.Controls.Add(this.devicesComboBox);
			this.devicesGroupBox.Location = new System.Drawing.Point(8, 8);
			this.devicesGroupBox.Name = "devicesGroupBox";
			this.devicesGroupBox.Size = new System.Drawing.Size(280, 48);
			this.devicesGroupBox.TabIndex = 1;
			this.devicesGroupBox.TabStop = false;
			this.devicesGroupBox.Text = "Available Devices";
			// 
			// devicesComboBox
			// 
			this.devicesComboBox.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.devicesComboBox.Location = new System.Drawing.Point(8, 16);
			this.devicesComboBox.Name = "devicesComboBox";
			this.devicesComboBox.Size = new System.Drawing.Size(264, 21);
			this.devicesComboBox.TabIndex = 0;
			// 
			// exitButton
			// 
			this.exitButton.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
			this.exitButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.exitButton.Location = new System.Drawing.Point(208, 248);
			this.exitButton.Name = "exitButton";
			this.exitButton.TabIndex = 2;
			this.exitButton.Text = "E&xit";
			this.exitButton.Click += new System.EventHandler(this.exitButton_Click);
			// 
			// copyButton
			// 
			this.copyButton.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
			this.copyButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.copyButton.Location = new System.Drawing.Point(128, 248);
			this.copyButton.Name = "copyButton";
			this.copyButton.TabIndex = 3;
			this.copyButton.Text = "&Copy";
			this.copyButton.Click += new System.EventHandler(this.copyButton_Click);
			// 
			// sourceTextBox
			// 
			this.sourceTextBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.sourceTextBox.Location = new System.Drawing.Point(8, 16);
			this.sourceTextBox.Name = "sourceTextBox";
			this.sourceTextBox.Size = new System.Drawing.Size(264, 20);
			this.sourceTextBox.TabIndex = 4;
			this.sourceTextBox.Text = "";
			// 
			// sourceSelectFile
			// 
			this.sourceSelectFile.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.sourceSelectFile.Location = new System.Drawing.Point(200, 88);
			this.sourceSelectFile.Name = "sourceSelectFile";
			this.sourceSelectFile.TabIndex = 5;
			this.sourceSelectFile.Text = "Select File";
			this.sourceSelectFile.Click += new System.EventHandler(this.sourceSelectFile_Click);
			// 
			// sourceSelectFolder
			// 
			this.sourceSelectFolder.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.sourceSelectFolder.Location = new System.Drawing.Point(120, 88);
			this.sourceSelectFolder.Name = "sourceSelectFolder";
			this.sourceSelectFolder.TabIndex = 6;
			this.sourceSelectFolder.Text = "Select Folder";
			this.sourceSelectFolder.Click += new System.EventHandler(this.sourceSelectFolder_Click);
			// 
			// fileProgressBar
			// 
			this.fileProgressBar.Dock = System.Windows.Forms.DockStyle.Fill;
			this.fileProgressBar.Location = new System.Drawing.Point(3, 16);
			this.fileProgressBar.Name = "fileProgressBar";
			this.fileProgressBar.Size = new System.Drawing.Size(274, 13);
			this.fileProgressBar.TabIndex = 8;
			// 
			// fileGroupBox
			// 
			this.fileGroupBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.fileGroupBox.Controls.Add(this.fileProgressBar);
			this.fileGroupBox.Location = new System.Drawing.Point(8, 272);
			this.fileGroupBox.Name = "fileGroupBox";
			this.fileGroupBox.Size = new System.Drawing.Size(280, 32);
			this.fileGroupBox.TabIndex = 9;
			this.fileGroupBox.TabStop = false;
			this.fileGroupBox.Text = "Current File";
			// 
			// overallGroupBox
			// 
			this.overallGroupBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.overallGroupBox.Controls.Add(this.overallProgressBar);
			this.overallGroupBox.Location = new System.Drawing.Point(8, 304);
			this.overallGroupBox.Name = "overallGroupBox";
			this.overallGroupBox.Size = new System.Drawing.Size(280, 32);
			this.overallGroupBox.TabIndex = 10;
			this.overallGroupBox.TabStop = false;
			this.overallGroupBox.Text = "Overall";
			// 
			// overallProgressBar
			// 
			this.overallProgressBar.Dock = System.Windows.Forms.DockStyle.Fill;
			this.overallProgressBar.Location = new System.Drawing.Point(3, 16);
			this.overallProgressBar.Name = "overallProgressBar";
			this.overallProgressBar.Size = new System.Drawing.Size(274, 13);
			this.overallProgressBar.TabIndex = 8;
			// 
			// sourceGroupBox
			// 
			this.sourceGroupBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.sourceGroupBox.Controls.Add(this.groupBox1);
			this.sourceGroupBox.Controls.Add(this.sourceTextBox);
			this.sourceGroupBox.Controls.Add(this.sourceSelectFile);
			this.sourceGroupBox.Controls.Add(this.sourceSelectFolder);
			this.sourceGroupBox.Location = new System.Drawing.Point(8, 56);
			this.sourceGroupBox.Name = "sourceGroupBox";
			this.sourceGroupBox.Size = new System.Drawing.Size(280, 120);
			this.sourceGroupBox.TabIndex = 11;
			this.sourceGroupBox.TabStop = false;
			this.sourceGroupBox.Text = "Source";
			// 
			// destinationGroupBox
			// 
			this.destinationGroupBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.destinationGroupBox.Controls.Add(this.createDirCheckBox);
			this.destinationGroupBox.Controls.Add(this.destinationComboBox);
			this.destinationGroupBox.Location = new System.Drawing.Point(8, 176);
			this.destinationGroupBox.Name = "destinationGroupBox";
			this.destinationGroupBox.Size = new System.Drawing.Size(280, 64);
			this.destinationGroupBox.TabIndex = 12;
			this.destinationGroupBox.TabStop = false;
			this.destinationGroupBox.Text = "Destination";
			// 
			// createDirCheckBox
			// 
			this.createDirCheckBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.createDirCheckBox.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.createDirCheckBox.Location = new System.Drawing.Point(8, 40);
			this.createDirCheckBox.Name = "createDirCheckBox";
			this.createDirCheckBox.Size = new System.Drawing.Size(264, 16);
			this.createDirCheckBox.TabIndex = 1;
			this.createDirCheckBox.Text = "Create directory if it doesn\'t exist";
			// 
			// destinationComboBox
			// 
			this.destinationComboBox.Location = new System.Drawing.Point(8, 16);
			this.destinationComboBox.Name = "destinationComboBox";
			this.destinationComboBox.Size = new System.Drawing.Size(264, 21);
			this.destinationComboBox.TabIndex = 0;
			// 
			// openFileDialog
			// 
			this.openFileDialog.Title = "Select file to copy";
			// 
			// matchTextBox
			// 
			this.matchTextBox.Location = new System.Drawing.Point(88, 16);
			this.matchTextBox.Name = "matchTextBox";
			this.matchTextBox.Size = new System.Drawing.Size(64, 20);
			this.matchTextBox.TabIndex = 2;
			this.matchTextBox.Text = "";
			// 
			// folderMatchLabel
			// 
			this.folderMatchLabel.Location = new System.Drawing.Point(8, 18);
			this.folderMatchLabel.Name = "folderMatchLabel";
			this.folderMatchLabel.Size = new System.Drawing.Size(80, 16);
			this.folderMatchLabel.TabIndex = 3;
			this.folderMatchLabel.Text = "Match Pattern:";
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.folderMatchLabel);
			this.groupBox1.Controls.Add(this.matchTextBox);
			this.groupBox1.Location = new System.Drawing.Point(8, 40);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(264, 40);
			this.groupBox1.TabIndex = 7;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Folder Options";
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(292, 342);
			this.Controls.Add(this.destinationGroupBox);
			this.Controls.Add(this.sourceGroupBox);
			this.Controls.Add(this.overallGroupBox);
			this.Controls.Add(this.fileGroupBox);
			this.Controls.Add(this.copyButton);
			this.Controls.Add(this.exitButton);
			this.Controls.Add(this.devicesGroupBox);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MinimumSize = new System.Drawing.Size(300, 376);
			this.Name = "MainForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "PPC Emulator File Copier";
			this.devicesGroupBox.ResumeLayout(false);
			this.fileGroupBox.ResumeLayout(false);
			this.overallGroupBox.ResumeLayout(false);
			this.sourceGroupBox.ResumeLayout(false);
			this.destinationGroupBox.ResumeLayout(false);
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		#region Button Events
		private void copyButton_Click(object sender, System.EventArgs eventArgs)
		{
			Microsoft.VisualStudio.DeviceConnectivity.QUEUING_ACTION qUEUING_ACTION;
			Microsoft.VisualStudio.DeviceConnectivity.FILETIME fILETIME1;
			Microsoft.VisualStudio.DeviceConnectivity.FILETIME fILETIME2;
			Microsoft.VisualStudio.DeviceConnectivity.FILETIME fILETIME3;
			ulong l;

			// save destination folder
			string destination = this.destinationComboBox.Text.Trim();
			if (destination != "")
			{
				if (destinationComboBox.Items.Contains(destination))
				{
					destinationComboBox.Items.Remove(destination);
					destinationComboBox.Items.Insert(0,destination);
				}
				else
				{
					destinationComboBox.Items.Insert(0,destination);
				}
				destinationComboBox.SelectedItem = destination;
				destinationComboBox.SelectAll();

				// determine if we are copying 1 or more files
				string[] files = new string[1];
				System.IO.FileAttributes sourceAttributes = System.IO.File.GetAttributes(this.sourceTextBox.Text);
				if (sourceAttributes == System.IO.FileAttributes.Directory)
				{
					files = System.IO.Directory.GetFiles(this.sourceTextBox.Text, this.matchTextBox.Text);
				}
				else
				{
					files[0] = this.sourceTextBox.Text;
				}
				this.overallProgressBar.Minimum = 0;
				this.overallProgressBar.Value = 0;
				this.overallProgressBar.Step = 1;
				this.overallProgressBar.Maximum = files.Length;
			

				// create the connection manager
				Microsoft.VisualStudio.DeviceConnectivity.IDevice iDevice = deviceList[this.devicesComboBox.SelectedIndex] as Microsoft.VisualStudio.DeviceConnectivity.IDevice;
				Microsoft.VisualStudio.DeviceConnectivity.ConnectionManagerServer srv = new Microsoft.VisualStudio.DeviceConnectivity.ConnectionManagerServer(iDevice, store.Transports, store.Startups);
			
			
				if (!srv.EstablishConnection())
				{
					System.Windows.Forms.MessageBox.Show("Unable to establish connection with emulator");
				}
				else
				{
					string destinationPath = System.IO.Path.GetFileName(destination);
					System.IO.FileAttributes fileAttributes = (System.IO.FileAttributes)0;
					try
					{
						srv.GetFileInfo(destinationPath, out fileAttributes, out l, out fILETIME1, out fILETIME2, out fILETIME3);
					}
					catch
					{
					}
					if ((int)(fileAttributes & System.IO.FileAttributes.Directory) == 16)
					{
						destinationPath = System.IO.Path.Combine(destinationPath, System.IO.Path.GetFileName(files[0]));
					}
					else
					{
						// try to make the dir
						if (this.createDirCheckBox.Checked)
						{
							srv.CreateDirectory(destinationPath);
							try
							{
								srv.GetFileInfo(destinationPath, out fileAttributes, out l, out fILETIME1, out fILETIME2, out fILETIME3);
							}
							catch
							{
							}
							if ((int)(fileAttributes & System.IO.FileAttributes.Directory) == 16)
							{
								destinationPath = System.IO.Path.Combine(destinationPath, System.IO.Path.GetFileName(files[0]));
							}
						}
					}
					if (srv.FileExists(destinationPath))
					{
						qUEUING_ACTION = (Microsoft.VisualStudio.DeviceConnectivity.QUEUING_ACTION)2;
					}
					else
					{
						qUEUING_ACTION = (Microsoft.VisualStudio.DeviceConnectivity.QUEUING_ACTION)0;
					}
					Microsoft.VisualStudio.DeviceConnectivity.CUSTOM_ATTRIBUTE cUSTOM_ATTRIBUTE = (Microsoft.VisualStudio.DeviceConnectivity.CUSTOM_ATTRIBUTE)0;
					try
					{
						destinationPath = System.IO.Path.GetFileName(destination);
						foreach (string file in files)
						{
							this.fileGroupBox.Text = "Current File - " + System.IO.Path.GetFileName(file);
							this.fileProgressBar.Value = 0;
							string destFile = System.IO.Path.Combine(destinationPath, System.IO.Path.GetFileName(file));
							srv.SendFile(file, destFile, qUEUING_ACTION, cUSTOM_ATTRIBUTE, new ProgressCallback(this));
							this.overallProgressBar.PerformStep();
						}
						System.Windows.Forms.MessageBox.Show("All files copied successfully!");
					}
					catch (System.Exception e)
					{
						System.Windows.Forms.MessageBox.Show("Failed to copy file\r\n" + e.ToString());
					}
				}
			}
			else
			{
				System.Windows.Forms.MessageBox.Show("Destination can not be empty");
			}
		}

		private void sourceSelectFile_Click(object sender, System.EventArgs e)
		{
			if (this.openFileDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
			{
				this.sourceTextBox.Text = this.openFileDialog.FileName;
			}
		}

		private void sourceSelectFolder_Click(object sender, System.EventArgs e)
		{
			System.Windows.Forms.FolderBrowserDialog fbd = new System.Windows.Forms.FolderBrowserDialog();
			if (fbd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
			{
				string directory = fbd.SelectedPath;
				this.sourceTextBox.Text = directory;
			}
		}

		private void exitButton_Click(object sender, System.EventArgs e)
		{
			this.Dispose();
		}
		#endregion

		#region Progress Callback
		public void Update(int percentage)
		{
			this.fileProgressBar.Value = percentage;
			System.Windows.Forms.Application.DoEvents();
		}

		private void ResetProgressBars()
		{
			this.fileProgressBar.Value = 0;
			this.fileProgressBar.Maximum = 100;
			this.fileProgressBar.Minimum = 0;
			this.fileProgressBar.Step = 1;
		}
		#endregion

		#region Get Device list
		private void FillDeviceList()
		{	
			System.Collections.IEnumerator iEnumerator = deviceList.GetEnumerator();
			try
			{
				while (iEnumerator.MoveNext())
				{
					Microsoft.VisualStudio.DeviceConnectivity.IDevice iDevice = (Microsoft.VisualStudio.DeviceConnectivity.IDevice)iEnumerator.Current;
					this.devicesComboBox.Items.Add(iDevice.Name);
				}
			}
			finally
			{
				System.IDisposable iDisposable = iEnumerator as System.IDisposable;
				if (iDisposable != null)
				{
					iDisposable.Dispose();
				}
			}
		}
		#endregion

		#region Load Platforms
		private void LoadAllPlatforms()
		{
			Microsoft.VisualStudio.DeviceConnectivity.ConMan conMan = new Microsoft.VisualStudio.DeviceConnectivity.ConMan();
			conMan.Initialize();
			store = conMan.DataStore;
			Microsoft.VisualStudio.DeviceConnectivity.IPlatformContainer iPlatformContainer = store.Platforms;
			System.Collections.IEnumerator iEnumerator1 = iPlatformContainer.EnumeratePlatforms().GetEnumerator();
			try
			{
				while (iEnumerator1.MoveNext())
				{
					Microsoft.VisualStudio.DeviceConnectivity.IPlatform iPlatform = (Microsoft.VisualStudio.DeviceConnectivity.IPlatform)iEnumerator1.Current;
					if (!(iPlatform.FindProperty("UserListed") == "no"))
					{
						System.Collections.IEnumerator iEnumerator2 = iPlatform.EnumeratePropertyNames().GetEnumerator();
						try
						{
							while (iEnumerator2.MoveNext())
							{
								string sourceFiles = (string)iEnumerator2.Current;
							}
						}
						finally
						{
							System.IDisposable iDisposable1 = iEnumerator2 as System.IDisposable;
							if (iDisposable1 != null)
							{
								iDisposable1.Dispose();
							}
						}
						System.Collections.IEnumerator iEnumerator3 = iPlatform.EnumerateMatchingDevicesAnd(new string[]{"CurrentStartup"}, new string[]{"emulator"}).GetEnumerator();
						try
						{
							while (iEnumerator3.MoveNext())
							{
								Microsoft.VisualStudio.DeviceConnectivity.IDevice iDevice = (Microsoft.VisualStudio.DeviceConnectivity.IDevice)iEnumerator3.Current;
								deviceList.Add(iDevice);
								System.Collections.IEnumerator iEnumerator4 = iDevice.EnumeratePropertyNames().GetEnumerator();
								try
								{
									while (iEnumerator4.MoveNext())
									{
										string destinationPath = (string)iEnumerator4.Current;
									}
								}
								finally
								{
									System.IDisposable iDisposable2 = iEnumerator4 as System.IDisposable;
									if (iDisposable2 != null)
									{
										iDisposable2.Dispose();
									}
								}
							}
						}
						finally
						{
							System.IDisposable iDisposable3 = iEnumerator3 as System.IDisposable;
							if (iDisposable3 != null)
							{
								iDisposable3.Dispose();
							}
						}
					}
				}
			}
			finally
			{
				System.IDisposable iDisposable4 = iEnumerator1 as System.IDisposable;
				if (iDisposable4 != null)
				{
					iDisposable4.Dispose();
				}
			}
		}
		#endregion
	}
}
