namespace Utilities.PPCEmulatorFileSender
{
	/// <summary>
	/// An object that can be serialized 
	/// Provides methods of serializing/deserializing to an XML file
	/// </summary>
	[System.Serializable]
	public class Properties
	{
		#region Variables
		private System.Collections.ArrayList destinations;
		private int selectedDevice;
		private string sourceFiles;
		private int destinationDirectory;
		private string fileName;
		private bool createDirectory;
		private string sourceMatch;
		#endregion

		#region Properties
		/// <summary>
		/// Property SourceMatch (string)
		/// </summary>
		public string SourceMatch
		{
			get
			{
				return this.sourceMatch;
			}
			set
			{
				this.sourceMatch = value;
			}
		}
		/// <summary>
		/// Property CreateDirectory (bool)
		/// </summary>
		public bool CreateDirectory
		{
			get
			{
				return this.createDirectory;
			}
			set
			{
				this.createDirectory = value;
			}
		}
		/// <summary>
		/// Property Destinations (System.Collections.ArrayList)
		/// </summary>
		public System.Collections.ArrayList Destinations
		{
			get
			{
				return this.destinations;
			}
			set
			{
				this.destinations = value;
			}
		}
		/// <summary>
		/// Property DestinationDirectory (int)
		/// </summary>
		public int DestinationDirectory
		{
			get
			{
				return this.destinationDirectory;
			}
			set
			{
				this.destinationDirectory = value;
			}
		}
		/// <summary>
		/// Property SourceFiles (string)
		/// </summary>
		public string SourceFiles
		{
			get
			{
				return this.sourceFiles;
			}
			set
			{
				this.sourceFiles = value;
			}
		}
		/// <summary>
		/// Property SelectedDevice (int)
		/// </summary>
		public int SelectedDevice
		{
			get
			{
				return this.selectedDevice;
			}
			set
			{
				this.selectedDevice = value;
			}
		}
		#endregion

		#region Constructor
		/// <summary>
		/// Constructor
		/// </summary>
		public Properties()
		{
			this.createDirectory = true;
			this.fileName = System.IO.Directory.GetCurrentDirectory() + "\\properties.xml";
			this.destinations = new System.Collections.ArrayList();
			this.selectedDevice = -1;
			this.sourceFiles = "";
			this.destinationDirectory = -1;
			this.sourceMatch = "*.*";
		}
		#endregion

		#region Serialization/Deserialization

		/// <summary>
		/// Deserializes the file into the object
		/// </summary>
		/// <returns>the object</returns>
		public Properties Deserialize()
		{
			return (Properties)Deserialize(fileName);
		}

		/// <summary>
		/// Deserializes the file into the object
		/// </summary>
		/// <param name="fileName">the file to deserialize</param>
		/// <returns>the object</returns>
		public Properties Deserialize(string fileName)
		{
			object o = System.Activator.CreateInstance(this.GetType());
			try
			{
				System.Xml.Serialization.XmlSerializer serializer = new System.Xml.Serialization.XmlSerializer(this.GetType());
				System.IO.TextReader reader = new System.IO.StreamReader(fileName);
				o = serializer.Deserialize(reader);
				reader.Close();
			}
			catch (System.Exception)
			{
				// just return a new object
			}
			return (Properties)o;
		}

		/// <summary>
		/// Serializes the object into the default file name
		/// </summary>
		/// <returns>success of the serialization</returns>
		public bool Serialize()
		{
			return this.Serialize(fileName);
		}

		/// <summary>
		/// Serializes the object into a file
		/// </summary>
		/// <param name="fileName">the file to serialize to</param>
		/// <returns>success of the serialization</returns>
		public bool Serialize(string fileName)
		{
			bool result = false;
			try
			{
				System.Xml.Serialization.XmlSerializer xs = new System.Xml.Serialization.XmlSerializer(this.GetType()); 
				System.IO.TextWriter writer = new System.IO.StreamWriter(fileName);
				xs.Serialize(writer, this);
				writer.Close();

				result = true;
			}
			catch (System.Exception e)
			{
				throw(e);
			}
			return result;
		}

		#endregion
	}
}
